@@ -11,14 +11,15 @@ class singleton(object):
 not_there = singleton('not_there')
 
 from testfixtures.comparison import (
-    Comparison, StringComparison, RoundComparison, compare, diff, RangeComparison
+    Comparison, StringComparison, RoundComparison, compare, diff, RangeComparison,
+    SequenceComparison, Subset, Permutation, MappingComparison
 )
 from testfixtures.tdatetime import test_datetime, test_date, test_time
 from testfixtures.logcapture import LogCapture, log_capture
 from testfixtures.outputcapture import OutputCapture
 from testfixtures.resolve import resolve
 from testfixtures.replace import Replacer, Replace, replace
-from testfixtures.shouldraise import ShouldRaise, should_raise
+from testfixtures.shouldraise import ShouldRaise, should_raise, ShouldAssert
 from testfixtures.shouldwarn import ShouldWarn, ShouldNotWarn
 from testfixtures.tempdirectory import TempDirectory, tempdir
 from testfixtures.utils import wrap, generator
