@@ -1,7 +1,7 @@
 from unittest import TestCase
 import sys
 
-from testfixtures import Comparison as C, TempDirectory, compare, diff
+from testfixtures import Comparison as C, TempDirectory, compare, diff, Comparison
 from testfixtures.compat import PY2, PY3, exception_module
 from testfixtures.shouldraise import ShouldAssert
 from testfixtures.tests.sample1 import SampleClassA, a_function
@@ -104,16 +104,11 @@ class TestC(TestCase):
             AClass(1, 2),
             )
 
-    def test_example_not_strict(self):
-        # Here, we only care about the 'x' attribute of
-        # the AClass object, so we turn strict mode off.
-        # With strict mode off, only attributes specified
-        # in the Comparison object will be checked, and
-        # any others will be ignored.
+    def test_example_partial(self):
         self.assertEqual(
             C('testfixtures.tests.test_comparison.AClass',
               x=1,
-              strict=False),
+              partial=True),
             AClass(1, 2),
             )
 
@@ -122,11 +117,11 @@ class TestC(TestCase):
         e = ValueError('some message')
         x, y = C(e), C(e)
         assert x != y
-        compare_repr(x, "<C(failed):{mod}.ValueError>wrong type</C>".format(
+        compare_repr(x, "<C:{mod}.ValueError(failed)>wrong type</>".format(
                             mod=exception_module))
         compare_repr(
             y,
-            "<C:{mod}.ValueError>args: ('some message',)</C>".format(
+            "<C:{mod}.ValueError>args: ('some message',)</>".format(
                 mod=exception_module)
         )
 
@@ -145,12 +140,12 @@ class TestC(TestCase):
         compare_repr(C(SampleClassA('something')),
                      "<C:testfixtures.tests.sample1.SampleClassA>"
                      "args: ('something',)"
-                     "</C>"
+                     "</>"
                      )
 
     def test_repr_exception(self):
         compare_repr(C(ValueError('something')),
-                     ("<C:{0}.ValueError>args: ('something',)</C>"
+                     ("<C:{0}.ValueError>args: ('something',)</>"
                       ).format(exception_module))
 
     def test_repr_exception_not_args(self):
@@ -166,13 +161,13 @@ class TestC(TestCase):
             + args +
             "x: 1\n"
             "y: 2\n"
-            "</C>"
+            "</C:testfixtures.tests.test_comparison.WeirdException>"
         )
 
     def test_repr_class_and_vars(self):
         compare_repr(
             C(SampleClassA, {'args': (1,)}),
-            "<C:testfixtures.tests.sample1.SampleClassA>args: (1,)</C>"
+            "<C:testfixtures.tests.sample1.SampleClassA>args: (1,)</>"
         )
 
     def test_repr_nested(self):
@@ -185,16 +180,16 @@ class TestC(TestCase):
             "  <C:testfixtures.tests.test_comparison.BClass>\n"
             "  x: 1\n"
             "  y: 2\n"
-            "  </C>\n"
-            "</C>"
+            "  </C:testfixtures.tests.test_comparison.BClass>\n"
+            "</C:testfixtures.tests.sample1.SampleClassA>"
             )
 
     def test_repr_failed_wrong_class(self):
         c = C('testfixtures.tests.test_comparison.AClass', x=1, y=2)
         assert c != BClass(1, 2)
         compare_repr(c,
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>"
-                     "wrong type</C>"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>"
+                     "wrong type</>"
                      )
 
     def test_repr_failed_all_reasons_in_one(self):
@@ -203,14 +198,14 @@ class TestC(TestCase):
         assert c != AClass(1, 2)
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
                      "attributes in Comparison but not actual:\n"
                      "'z': 'missing'\n\n"
                      "attributes in actual but not Comparison:\n"
                      "'x': 1\n\n"
                      "attributes differ:\n"
                      "'y': 5 (Comparison) != 2 (actual)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.AClass>",
                      )
 
     def test_repr_failed_not_in_other(self):
@@ -219,39 +214,38 @@ class TestC(TestCase):
         assert c != AClass(1, 2)
         compare_repr(c ,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
                      "attributes same:\n"
                      "['x', 'y']\n\n"
                      "attributes in Comparison but not actual:\n"
                      "'z': (3,)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.AClass>",
                      )
 
-    def test_repr_failed_not_in_self_strict(self):
+    def test_repr_failed_not_in_self(self):
         c = C('testfixtures.tests.test_comparison.AClass', y=2)
-        assert c != AClass((1, ), 2)
+        assert c != AClass(x=(1, ), y=2)
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
                      "attributes same:\n"
                      "['y']\n\n"
                      "attributes in actual but not Comparison:\n"
                      "'x': (1,)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.AClass>",
                      )
 
-    def test_repr_failed_not_in_self_not_strict(self):
-        c = C('testfixtures.tests.test_comparison.AClass',
-              x=1, y=2, z=(3, ))
-        assert c != AClass(1, 2)
+    def test_repr_failed_not_in_self_partial(self):
+        c = C('testfixtures.tests.test_comparison.AClass', x=1, y=2, z=(3, ), partial=True)
+        assert c != AClass(x=1, y=2)
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
                      "attributes same:\n"
                      "['x', 'y']\n\n"
                      "attributes in Comparison but not actual:\n"
                      "'z': (3,)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.AClass>",
                      )
 
     def test_repr_failed_one_attribute_not_equal(self):
@@ -259,12 +253,12 @@ class TestC(TestCase):
         assert c != AClass(1, (3, ))
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
                      "attributes same:\n"
                      "['x']\n\n"
                      "attributes differ:\n"
                      "'y': (2,) (Comparison) != (3,) (actual)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.AClass>",
                      )
 
     def test_repr_failed_nested(self):
@@ -278,20 +272,20 @@ class TestC(TestCase):
         compare_repr(
             left_side,
             "[\n"
-            "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+            "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
             "attributes same:\n"
             "['x']\n\n"
             "attributes differ:\n"
             "'y': 2 (Comparison) != 3 (actual)\n"
-            "</C>, \n"
+            "</C:testfixtures.tests.test_comparison.AClass>, \n"
             "<C:testfixtures.tests.test_comparison.BClass>\n"
             "x: \n"
             "  <C:testfixtures.tests.test_comparison.AClass>\n"
             "  x: 1\n"
             "  y: 2\n"
-            "  </C>\n"
+            "  </C:testfixtures.tests.test_comparison.AClass>\n"
             "y: <C:testfixtures.tests.test_comparison.AClass>\n"
-            "</C>]"
+            "</C:testfixtures.tests.test_comparison.BClass>]"
         )
 
         compare_repr(right_side, "[<AClass>, <AClass>]")
@@ -299,7 +293,7 @@ class TestC(TestCase):
     def test_repr_failed_nested_failed(self):
         left_side = [C(AClass, x=1, y=2),
                      C(BClass,
-                       x=C(AClass, x=1, strict=False),
+                       x=C(AClass, x=1, partial=True),
                        y=C(AClass, z=2))]
         right_side = [AClass(1, 2),
                       BClass(AClass(1, 2), AClass(1, 2))]
@@ -313,20 +307,20 @@ class TestC(TestCase):
             "<C:testfixtures.tests.test_comparison.AClass>\n"
             "x: 1\n"
             "y: 2\n"
-            "</C>, \n"
-            "<C(failed):testfixtures.tests.test_comparison.BClass>\n"
+            "</C:testfixtures.tests.test_comparison.AClass>, \n"
+            "<C:testfixtures.tests.test_comparison.BClass(failed)>\n"
             "attributes same:\n"
             "['x']\n\n"
             "attributes differ:\n"
             "'y': \n"
-            "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+            "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
             "attributes in Comparison but not actual:\n"
             "'z': 2\n\n"
             "attributes in actual but not Comparison:\n"
             "'x': 1\n"
             "'y': 2\n"
-            "</C> (Comparison) != <AClass> (actual)\n"
-            "</C>]",
+            "</C:testfixtures.tests.test_comparison.AClass> (Comparison) != <AClass> (actual)\n"
+            "</C:testfixtures.tests.test_comparison.BClass>]",
         )
 
         compare_repr(right_side, '[<AClass>, <BClass>]')
@@ -336,12 +330,12 @@ class TestC(TestCase):
         assert c != AClass(1, 3)
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
                      "attributes same:\n"
                      "['x']\n\n"
                      "attributes differ:\n"
                      "'y': 2 (Comparison) != 3 (actual)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.AClass>",
                      )
 
         assert c == AClass(1, 2)
@@ -349,12 +343,12 @@ class TestC(TestCase):
         assert c != AClass(3, 2)
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.AClass>\n"
+                     "<C:testfixtures.tests.test_comparison.AClass(failed)>\n"
                      "attributes same:\n"
                      "['y']\n\n"
                      "attributes differ:\n"
                      "'x': 1 (Comparison) != 3 (actual)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.AClass>",
                      )
 
     def test_first(self):
@@ -419,92 +413,92 @@ class TestC(TestCase):
             C(SampleClassA(), args=(1,))
             )
 
-    def test_object_not_strict(self):
+    def test_object_partial(self):
         # only attributes on comparison object
         # are used
         self.assertEqual(
-            C(AClass(1), strict=False),
+            C(AClass(1), partial=True),
             AClass(1, 2),
             )
 
-    def run_property_equal_test(self, strict):
+    def run_property_equal_test(self, partial):
         class SomeClass(object):
             @property
             def prop(self):
                 return 1
 
         self.assertEqual(
-            C(SomeClass, prop=1, strict=strict),
+            C(SomeClass, prop=1, partial=partial),
             SomeClass()
         )
 
-    def test_property_equal_strict(self):
-        self.run_property_equal_test(strict=True)
+    def test_property_equal(self):
+        self.run_property_equal_test(partial=False)
 
-    def test_property_equal_not_strict(self):
-        self.run_property_equal_test(strict=False)
+    def test_property_equal_partial(self):
+        self.run_property_equal_test(partial=True)
 
-    def run_property_not_equal_test(self, strict):
+    def run_property_not_equal_test(self, partial):
         class SomeClass(object):
             @property
             def prop(self):
                 return 1
 
-        c = C(SomeClass, prop=2, strict=strict)
+        c = C(SomeClass, prop=2, partial=partial)
         self.assertNotEqual(c, SomeClass())
         compare_repr(
             c,
             "\n"
-            "<C(failed):testfixtures.tests.test_comparison.SomeClass>\n"
+            "<C:testfixtures.tests.test_comparison.SomeClass(failed)>\n"
             "attributes differ:\n"
             "'prop': 2 (Comparison) != 1 (actual)\n"
-            "</C>")
+            "</C:testfixtures.tests.test_comparison.SomeClass>")
 
-    def test_property_not_equal_strict(self):
-        self.run_property_not_equal_test(strict=True)
+    def test_property_not_equal(self):
+        self.run_property_not_equal_test(partial=False)
 
-    def test_property_not_equal_not_strict(self):
-        self.run_property_not_equal_test(strict=False)
+    def test_property_not_equal_partial(self):
+        self.run_property_not_equal_test(partial=True)
 
-    def run_method_equal_test(self, strict):
+    def run_method_equal_test(self, partial):
         class SomeClass(object):
             def method(self):
                 pass  # pragma: no cover
 
         instance = SomeClass()
         self.assertEqual(
-            C(SomeClass, method=instance.method, strict=strict),
+            C(SomeClass, method=instance.method, partial=partial),
             instance
         )
 
-    def test_method_equal_strict(self):
-        self.run_method_equal_test(strict=True)
+    def test_method_equal(self):
+        self.run_method_equal_test(partial=False)
 
-    def test_method_equal_not_strict(self):
-        self.run_method_equal_test(strict=False)
+    def test_method_equal_partial(self):
+        self.run_method_equal_test(partial=True)
 
-    def run_method_not_equal_test(self, strict):
+    def run_method_not_equal_test(self, partial):
         class SomeClass(object): pass
         instance = SomeClass()
         instance.method = min
 
-        c = C(SomeClass, method=max, strict=strict)
+        c = C(SomeClass, method=max, partial=partial)
         self.assertNotEqual(c, instance)
         compare_repr(
             c,
             "\n"
-            "<C(failed):testfixtures.tests.test_comparison.SomeClass>\n"
+            "<C:testfixtures.tests.test_comparison.SomeClass(failed)>\n"
             "attributes differ:\n"
             "'method': <built-in function max> (Comparison)"
             " != <built-in function min> (actual)\n"
-            "</C>"
+            "</C:testfixtures.tests.test_comparison.SomeClass>"
         )
 
-    def test_method_not_equal_strict(self):
-        self.run_method_not_equal_test(strict=True)
+    def test_method_not_equal(self):
+        self.run_method_not_equal_test(partial=False)
 
-    def test_method_not_equal_not_strict(self):
-        self.run_method_not_equal_test(strict=False)
+    def test_method_not_equal_partial(self):
+        self.run_method_not_equal_test(partial=True)
 
     def test_exception(self):
         self.assertEqual(
@@ -549,28 +543,28 @@ class TestC(TestCase):
             f.close()
         if PY3:
             c = C('io.TextIOWrapper', name=path, mode='r', closed=False,
-                  strict=False)
+                  partial=True)
             assert f != c
             compare_repr(c,
                          "\n"
-                         "<C(failed):_io.TextIOWrapper>\n"
+                         "<C:_io.TextIOWrapper(failed)>\n"
                          "attributes same:\n"
                          "['mode', 'name']\n\n"
                          "attributes differ:\n"
                          "'closed': False (Comparison) != True (actual)\n"
-                         "</C>",
+                         "</C:_io.TextIOWrapper>",
                          )
         else:
-            c = C(file, name=path, mode='r', closed=False, strict=False)
+            c = C(file, name=path, mode='r', closed=False, partial=True)
             assert f != c
             compare_repr(c,
                          "\n"
-                         "<C(failed):__builtin__.file>\n"
+                         "<C:__builtin__.file(failed)>\n"
                          "attributes same:\n"
                          "['mode', 'name']\n\n"
                          "attributes differ:\n"
                          "'closed': False (Comparison) != True (actual)\n"
-                         "</C>",
+                         "</C:__builtin__.file>",
                          )
 
     def test_file_same(self):
@@ -582,52 +576,52 @@ class TestC(TestCase):
             self.assertEqual(
                 f,
                 C('io.TextIOWrapper', name=path, mode='r', closed=True,
-                  strict=False)
+                  partial=True)
                 )
         else:
             self.assertEqual(
                 f,
-                C(file, name=path, mode='r', closed=True, strict=False)
+                C(file, name=path, mode='r', closed=True, partial=True)
                 )
 
     def test_no___dict___strict(self):
         c = C(X, x=1)
         assert c != X()
         compare_repr(c, "\n"
-                        "<C(failed):testfixtures.tests.test_comparison.X>\n"
+                        "<C:testfixtures.tests.test_comparison.X(failed)>\n"
                         "attributes in Comparison but not actual:\n"
                         "'x': 1\n"
-                        "</C>")
+                        "</C:testfixtures.tests.test_comparison.X>")
 
-    def test_no___dict___not_strict_same(self):
+    def test_no___dict___partial_same(self):
         x = X()
         x.x = 1
-        self.assertEqual(C(X, x=1, strict=False), x)
+        self.assertEqual(C(X, x=1, partial=True), x)
 
-    def test_no___dict___not_strict_missing_attr(self):
-        c = C(X, x=1, strict=False)
+    def test_no___dict___partial_missing_attr(self):
+        c = C(X, x=1, partial=True)
         assert c != X()
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.X>\n"
+                     "<C:testfixtures.tests.test_comparison.X(failed)>\n"
                      "attributes in Comparison but not actual:\n"
                      "'x': 1\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.X>",
                      )
 
-    def test_no___dict___not_strict_different(self):
+    def test_no___dict___partial_different(self):
         x = X()
         x.x = 2
-        c = C(X, x=1, y=2, strict=False)
+        c = C(X, x=1, y=2, partial=True)
         assert c != x
         compare_repr(c,
                      "\n"
-                     "<C(failed):testfixtures.tests.test_comparison.X>\n"
+                     "<C:testfixtures.tests.test_comparison.X(failed)>\n"
                      "attributes in Comparison but not actual:\n"
                      "'y': 2\n\n"
                      "attributes differ:\n"
                      "'x': 1 (Comparison) != 2 (actual)\n"
-                     "</C>",
+                     "</C:testfixtures.tests.test_comparison.X>",
                      )
 
     def test_compared_object_defines_eq(self):
@@ -667,10 +661,10 @@ class TestC(TestCase):
         c == Annoying()
         compare_repr(
             c,
-            '\n<C(failed):testfixtures.tests.test_comparison.Annoying>\n'
+            '\n<C:testfixtures.tests.test_comparison.Annoying(failed)>\n'
             'attributes differ:\n'
             "'eq_called': 1 (Comparison) != 0 (actual)\n"
-            '</C>'
+            '</C:testfixtures.tests.test_comparison.Annoying>'
         )
 
     def test_importerror(self):
@@ -706,3 +700,39 @@ class TestC(TestCase):
         else:
             expected = "<C:<class '.'>>"
         self.assertEqual(repr(c), expected)
+
+    def test_missing_expected_attribute_strict(self):
+
+        class MyClass(object):
+            def __init__(self, **attrs):
+                self.__dict__.update(attrs)
+
+        c = Comparison(MyClass, b=2, c=3, strict=True)
+        assert c != MyClass(a=1, b=2)
+
+    def test_missing_expected_attribute_not_strict(self):
+
+        class MyClass(object):
+            def __init__(self, **attrs):
+                self.__dict__.update(attrs)
+
+        c = Comparison(MyClass, b=2, c=3, strict=False)
+        assert c != MyClass(a=1, b=2)
+
+    def test_extra_expected_attribute_strict(self):
+
+        class MyClass(object):
+            def __init__(self, **attrs):
+                self.__dict__.update(attrs)
+
+        c = Comparison(MyClass, a=1, strict=True)
+        assert c != MyClass(a=1, b=2)
+
+    def test_extra_expected_attribute_not_strict(self):
+
+        class MyClass(object):
+            def __init__(self, **attrs):
+                self.__dict__.update(attrs)
+
+        c = Comparison(MyClass, a=1, strict=False)
+        assert c == MyClass(a=1, b=2)
